@@ -1,9 +1,11 @@
 use strict;
 use warnings;
 
-package Cond::Expr; # git description: 0.03-1-ge873dfc
-# ABSTRACT: conditionals as expressions
-$Cond::Expr::VERSION = '0.04';
+package Cond::Expr; # git description: 0.04-25-gb42799c
+# ABSTRACT: Conditionals as expressions
+
+our $VERSION = '0.05';
+
 use Sub::Exporter -setup => {
     exports => ['cond'],
     groups  => { default => ['cond'] },
@@ -16,7 +18,7 @@ use XSLoader;
 
 XSLoader::load(
     __PACKAGE__,
-    $Cond::Expr::{VERSION} ? ${ $Cond::Expr::{VERSION} } : (),
+    $VERSION,
 );
 
 #pod =head1 SYNOPSIS
@@ -58,11 +60,11 @@ XSLoader::load(
 #pod
 #pod   my %args = (
 #pod       foo => 'bar',
-#pod       (($answer == 42)
-#pod           ? (answer => $answer)
-#pod               : ($answer)
-#pod                   ? (wrong_answer => 1)
-#pod                       : (no_answer => 1)),
+#pod       (
+#pod             ($answer == 42) ? (answer => $answer)
+#pod           : ($answer)       ? (wrong_answer => 1)
+#pod           :                   (no_answer => 1)
+#pod       ),
 #pod   );
 #pod
 #pod can be used to achieve functionality similar to what this module provides. In
@@ -97,11 +99,11 @@ __END__
 
 =head1 NAME
 
-Cond::Expr - conditionals as expressions
+Cond::Expr - Conditionals as expressions
 
 =head1 VERSION
 
-version 0.04
+version 0.05
 
 =head1 SYNOPSIS
 
@@ -142,11 +144,11 @@ Using nested ternary C<?:> expressions, such as in
 
   my %args = (
       foo => 'bar',
-      (($answer == 42)
-          ? (answer => $answer)
-              : ($answer)
-                  ? (wrong_answer => 1)
-                      : (no_answer => 1)),
+      (
+            ($answer == 42) ? (answer => $answer)
+          : ($answer)       ? (wrong_answer => 1)
+          :                   (no_answer => 1)
+      ),
   );
 
 can be used to achieve functionality similar to what this module provides. In
@@ -171,11 +173,40 @@ scalar context, respectively.
 Due to the particular XS interfaces being used, this module requires a minimum
 Perl version of 5.014.
 
+=head1 SUPPORT
+
+Bugs may be submitted through L<the RT bug tracker|https://rt.cpan.org/Public/Dist/Display.html?Name=Cond-Expr>
+(or L<bug-Cond-Expr@rt.cpan.org|mailto:bug-Cond-Expr@rt.cpan.org>).
+
 =head1 AUTHOR
 
 Florian Ragwitz <rafl@debian.org>
 
-=head1 COPYRIGHT AND LICENSE
+=head1 CONTRIBUTORS
+
+=for stopwords Karen Etheridge David Mitchell Olivier Mengué Sawyer X
+
+=over 4
+
+=item *
+
+Karen Etheridge <ether@cpan.org>
+
+=item *
+
+David Mitchell <davem@iabyn.com>
+
+=item *
+
+Olivier Mengué <dolmen@cpan.org>
+
+=item *
+
+Sawyer X <xsawyerx@cpan.org>
+
+=back
+
+=head1 COPYRIGHT AND LICENCE
 
 This software is copyright (c) 2012 by Florian Ragwitz.
 
